/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.api;

// for slots manipulation
import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * MOF 2.0 Element (UML Element actually).
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: Element.java 555 2011-03-12 17:23:39Z yegor256@yahoo.com $
 */
public final class Element {

    /**
     * Map of slots.
     */
    private Map<String, String> slots = new HashMap<String, String>();

    /**
     * ID of the element.
     */
    private String name;

    /**
     * Name of MOF meta-class. For example it could be "Class"
     * or "Package", or "File".
     */
    private String type;

    /**
     * Public ctor.
     * @param pname The id of the element
     * @param ptype The name of the meta-class.
     */
    public Element(final String pname, final String ptype) {
        super();
        this.name = pname;
        this.type = ptype;
    }

    /**
     * Get instance name.
     * @return The name
     */
    public String name() {
        return this.name;
    }

    /**
     * Get class name.
     * @return The name
     */
    public String type() {
        return this.type;
    }

    /**
     * This element contains given slot name?
     * @param key Slot name
     * @return Contains?
     */
    public boolean containsKey(final String key) {
        return this.slots.containsKey(key);
    }

    /**
     * Get slot by name.
     * @param key Slot name
     * @return The value
     */
    public String get(final String key) {
        return this.slots.get(key);
    }

    /**
     * Set slot value.
     * @param key Slot name
     * @param value The value
     */
    public void put(final String key, final String value) {
        this.slots.put(key, value);
    }

    /**
     * Set full collection of slots.
     * @return The collection
     */
    public Collection<Map.Entry<String, String>> entrySet() {
        return this.slots.entrySet();
    }

}
