/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.api;

/**
 * Loader of Maven artifacts. The loader has to load the artifact
 * using its Maven coordinates, and all its dependencies. In other words,
 * it has to enable instantiation of artifact "worker". In order
 * to do this the loader has to downalod somewhere and allocate
 * necessary JAR files in the "classpath".
 *
 * <p>When the JAR is loaded the Loader has to get <tt>rom.xml</tt>
 * resource out of it, convert to {@link ROM}, and return.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: Loader.java 668 2011-03-14 22:35:32Z yegor256@yahoo.com $
 */
public interface Loader {

    /**
     * Load an artifact using its coordinates.
     * @param artifact The artifact to load
     * @return The {@link ROM} abstraction of the found
     *         <tt>rom.xml</tt> file
     * @throws LoadingException If the provided artifact is
     *         not a valid Reader for some reason
     */
    ROM load(final Artifact artifact) throws LoadingException;

    /**
     * Load a class by its name.
     * @param name The name of the class
     * @return The {@link Class} by the name
     * @throws LoadingException If some problem occurs
     */
    Class forName(final String name) throws LoadingException;

}
