/**
 * Copyright (c) 2011, REMPL.com
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1) Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 * 2) Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following
 * disclaimer in the documentation and/or other materials provided
 * with the distribution.
 * 3) Neither the name of the REMPL.com nor the names of its
 * contributors may be used to endorse or promote products derived
 * from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL
 * THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.rempl.api;

// collections
import java.util.ArrayList;
import java.util.Collection;

// string processing
import org.apache.commons.lang.StringUtils;

// DOM
import org.w3c.dom.NodeList;

/**
 * Convert XML to the type requested.
 *
 * @author Yegor Bugayenko (yegor@rempl.com)
 * @version $Id: ROMDexml.java 692 2011-03-16 18:07:50Z yegor256@yahoo.com $
 */
final class ROMDexml {

    /**
     * Create configuration.
     * @param list The node list
     * @param type The type to convert to
     * @return The result
     * @see ROMConfiguration#get(String,Class)
     */
    public Object convert(final NodeList list, final Class<?> type) {
        Object value;
        if (type.equals(String.class)) {
            if (list.item(0) == null) {
                throw RuntimeProblem.make("not found");
            }
            value = StringUtils.strip(list.item(0).getNodeValue());
        } else if (type.equals(String[].class)) {
            final Collection<String> items = new ArrayList<String>();
            for (int idx = 0; idx < list.getLength(); idx += 1) {
                items.add(StringUtils.strip(list.item(idx).getNodeValue()));
            }
            value = items;
        } else {
            throw RuntimeProblem.make(
                "JAXB manipulations are not implemented yet in get(), you can't"
                + " get any types except of java.lang.String"
            );
        }
        return value;
    }

}
